# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_validate_api_client.api_client import ApiClient


class AddressApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def address_check_eu_membership(self, input, **kwargs):  # noqa: E501
        """Check if a country is a member of the European Union (EU)  # noqa: E501

        Checks if the input country is a member of the European Union or not.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_check_eu_membership(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateCountryRequest input: Input request (required)
        :return: ValidateCountryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_check_eu_membership_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_check_eu_membership_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_check_eu_membership_with_http_info(self, input, **kwargs):  # noqa: E501
        """Check if a country is a member of the European Union (EU)  # noqa: E501

        Checks if the input country is a member of the European Union or not.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_check_eu_membership_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateCountryRequest input: Input request (required)
        :return: ValidateCountryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_check_eu_membership" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_check_eu_membership`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/country/check-eu-membership', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateCountryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_country(self, input, **kwargs):  # noqa: E501
        """Validate and normalize country information, return ISO 3166-1 country codes and country name  # noqa: E501

        Validates and normalizes country information, and returns key information about a country, as well as whether it is a member of the European Union.  Also returns distinct time zones in the country.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_country(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateCountryRequest input: Input request (required)
        :return: ValidateCountryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_country_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_country_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_country_with_http_info(self, input, **kwargs):  # noqa: E501
        """Validate and normalize country information, return ISO 3166-1 country codes and country name  # noqa: E501

        Validates and normalizes country information, and returns key information about a country, as well as whether it is a member of the European Union.  Also returns distinct time zones in the country.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_country_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateCountryRequest input: Input request (required)
        :return: ValidateCountryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_country" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_country`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/country', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateCountryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_country_list(self, **kwargs):  # noqa: E501
        """Get a list of ISO 3166-1 countries  # noqa: E501

        Enumerates the list of ISO 3166-1 countries, including name, country codes, and more.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_country_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CountryListResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_country_list_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.address_country_list_with_http_info(**kwargs)  # noqa: E501
            return data

    def address_country_list_with_http_info(self, **kwargs):  # noqa: E501
        """Get a list of ISO 3166-1 countries  # noqa: E501

        Enumerates the list of ISO 3166-1 countries, including name, country codes, and more.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_country_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CountryListResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_country_list" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/country/list', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CountryListResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_geocode(self, input, **kwargs):  # noqa: E501
        """Geocode a street address into latitude and longitude  # noqa: E501

        Geocodes a street address into latitude and longitude.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_geocode(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateAddressRequest input: Input parse request (required)
        :return: ValidateAddressResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_geocode_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_geocode_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_geocode_with_http_info(self, input, **kwargs):  # noqa: E501
        """Geocode a street address into latitude and longitude  # noqa: E501

        Geocodes a street address into latitude and longitude.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_geocode_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateAddressRequest input: Input parse request (required)
        :return: ValidateAddressResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_geocode" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_geocode`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/geocode', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateAddressResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_get_country_currency(self, input, **kwargs):  # noqa: E501
        """Get the currency of the input country  # noqa: E501

        Gets the currency information for the input country, including the ISO three-letter country code, currency symbol, and English currency name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_get_country_currency(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateCountryRequest input: Input request (required)
        :return: ValidateCountryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_get_country_currency_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_get_country_currency_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_get_country_currency_with_http_info(self, input, **kwargs):  # noqa: E501
        """Get the currency of the input country  # noqa: E501

        Gets the currency information for the input country, including the ISO three-letter country code, currency symbol, and English currency name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_get_country_currency_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateCountryRequest input: Input request (required)
        :return: ValidateCountryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_get_country_currency" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_get_country_currency`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/country/get-currency', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateCountryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_get_country_region(self, input, **kwargs):  # noqa: E501
        """Get the region, subregion and continent of the country  # noqa: E501

        Gets the continent information including region and subregion for the input country.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_get_country_region(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateCountryRequest input: Input request (required)
        :return: ValidateCountryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_get_country_region_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_get_country_region_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_get_country_region_with_http_info(self, input, **kwargs):  # noqa: E501
        """Get the region, subregion and continent of the country  # noqa: E501

        Gets the continent information including region and subregion for the input country.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_get_country_region_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateCountryRequest input: Input request (required)
        :return: ValidateCountryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_get_country_region" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_get_country_region`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/country/get-region', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateCountryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_get_timezone(self, input, **kwargs):  # noqa: E501
        """Gets IANA/Olsen time zones for a country  # noqa: E501

        Gets the IANA/Olsen time zones for a country.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_get_timezone(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetTimezonesRequest input: Input request (required)
        :return: GetTimezonesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_get_timezone_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_get_timezone_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_get_timezone_with_http_info(self, input, **kwargs):  # noqa: E501
        """Gets IANA/Olsen time zones for a country  # noqa: E501

        Gets the IANA/Olsen time zones for a country.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_get_timezone_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetTimezonesRequest input: Input request (required)
        :return: GetTimezonesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_get_timezone" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_get_timezone`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/country/get-timezones', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetTimezonesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_normalize_address(self, input, **kwargs):  # noqa: E501
        """Normalize a street address  # noqa: E501

        Normalizes an input structured street address is valid or invalid.  If the address is valid, also returns the latitude and longitude of the address.  Supports all major international addresses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_normalize_address(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateAddressRequest input: Input parse request (required)
        :return: NormalizeAddressResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_normalize_address_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_normalize_address_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_normalize_address_with_http_info(self, input, **kwargs):  # noqa: E501
        """Normalize a street address  # noqa: E501

        Normalizes an input structured street address is valid or invalid.  If the address is valid, also returns the latitude and longitude of the address.  Supports all major international addresses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_normalize_address_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateAddressRequest input: Input parse request (required)
        :return: NormalizeAddressResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_normalize_address" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_normalize_address`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/street-address/normalize', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NormalizeAddressResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_parse_string(self, input, **kwargs):  # noqa: E501
        """Parse an unstructured input text string into an international, formatted address  # noqa: E501

        Uses machine learning and Natural Language Processing (NLP) to handle a wide array of cases, including non-standard and unstructured address strings across a wide array of countries and address formatting norms.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_parse_string(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ParseAddressRequest input: Input parse request (required)
        :return: ParseAddressResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_parse_string_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_parse_string_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_parse_string_with_http_info(self, input, **kwargs):  # noqa: E501
        """Parse an unstructured input text string into an international, formatted address  # noqa: E501

        Uses machine learning and Natural Language Processing (NLP) to handle a wide array of cases, including non-standard and unstructured address strings across a wide array of countries and address formatting norms.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_parse_string_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ParseAddressRequest input: Input parse request (required)
        :return: ParseAddressResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_parse_string" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_parse_string`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/parse', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ParseAddressResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_reverse_geocode_address(self, input, **kwargs):  # noqa: E501
        """Reverse geocode a lattitude and longitude into an address  # noqa: E501

        Converts lattitude and longitude coordinates into an address through reverse-geocoding.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_reverse_geocode_address(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReverseGeocodeAddressRequest input: Input reverse geocoding request (required)
        :return: ReverseGeocodeAddressResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_reverse_geocode_address_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_reverse_geocode_address_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_reverse_geocode_address_with_http_info(self, input, **kwargs):  # noqa: E501
        """Reverse geocode a lattitude and longitude into an address  # noqa: E501

        Converts lattitude and longitude coordinates into an address through reverse-geocoding.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_reverse_geocode_address_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReverseGeocodeAddressRequest input: Input reverse geocoding request (required)
        :return: ReverseGeocodeAddressResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_reverse_geocode_address" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_reverse_geocode_address`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/geocode/reverse', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ReverseGeocodeAddressResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_validate_address(self, input, **kwargs):  # noqa: E501
        """Validate a street address  # noqa: E501

        Determines if an input structured street address is valid or invalid.  If the address is valid, also returns the latitude and longitude of the address.  Supports all major international addresses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_validate_address(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateAddressRequest input: Input parse request (required)
        :return: ValidateAddressResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_validate_address_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_validate_address_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_validate_address_with_http_info(self, input, **kwargs):  # noqa: E501
        """Validate a street address  # noqa: E501

        Determines if an input structured street address is valid or invalid.  If the address is valid, also returns the latitude and longitude of the address.  Supports all major international addresses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_validate_address_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateAddressRequest input: Input parse request (required)
        :return: ValidateAddressResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_validate_address" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_validate_address`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/street-address', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateAddressResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_validate_city(self, input, **kwargs):  # noqa: E501
        """Validate a City and State/Province combination, get location information about it  # noqa: E501

        Checks if the input city and state name or code is valid, and returns information about it such as normalized City name, State name and more.  Supports all major international addresses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_validate_city(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateCityRequest input: Input parse request (required)
        :return: ValidateCityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_validate_city_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_validate_city_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_validate_city_with_http_info(self, input, **kwargs):  # noqa: E501
        """Validate a City and State/Province combination, get location information about it  # noqa: E501

        Checks if the input city and state name or code is valid, and returns information about it such as normalized City name, State name and more.  Supports all major international addresses.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_validate_city_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateCityRequest input: Input parse request (required)
        :return: ValidateCityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_validate_city" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_validate_city`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/city', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateCityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_validate_postal_code(self, input, **kwargs):  # noqa: E501
        """Validate a postal code, get location information about it  # noqa: E501

        Checks if the input postal code is valid, and returns information about it such as City, State and more.  Supports all major countries.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_validate_postal_code(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidatePostalCodeRequest input: Input parse request (required)
        :return: ValidatePostalCodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_validate_postal_code_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_validate_postal_code_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_validate_postal_code_with_http_info(self, input, **kwargs):  # noqa: E501
        """Validate a postal code, get location information about it  # noqa: E501

        Checks if the input postal code is valid, and returns information about it such as City, State and more.  Supports all major countries.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_validate_postal_code_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidatePostalCodeRequest input: Input parse request (required)
        :return: ValidatePostalCodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_validate_postal_code" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_validate_postal_code`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/postal-code', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidatePostalCodeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def address_validate_state(self, input, **kwargs):  # noqa: E501
        """Validate a state or province, name or abbreviation, get location information about it  # noqa: E501

        Checks if the input state name or code is valid, and returns information about it such as normalized State name and more.  Supports all major countries.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_validate_state(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateStateRequest input: Input parse request (required)
        :return: ValidateStateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.address_validate_state_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.address_validate_state_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def address_validate_state_with_http_info(self, input, **kwargs):  # noqa: E501
        """Validate a state or province, name or abbreviation, get location information about it  # noqa: E501

        Checks if the input state name or code is valid, and returns information about it such as normalized State name and more.  Supports all major countries.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.address_validate_state_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateStateRequest input: Input parse request (required)
        :return: ValidateStateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method address_validate_state" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `address_validate_state`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/address/state', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateStateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_validate_api_client.api_client import ApiClient


class TextInputApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def text_input_check_sql_injection(self, value, **kwargs):  # noqa: E501
        """Check text input for SQL Injection (SQLI) attacks  # noqa: E501

        Detects SQL Injection (SQLI) attacks from text input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.text_input_check_sql_injection(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :param str detection_level: Set to Normal to target a high-security SQL Injection detection level with a very low false positive rate; select High to target a very-high security SQL Injection detection level with higher false positives.  Default is Normal (recommended).
        :return: SqlInjectionDetectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.text_input_check_sql_injection_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.text_input_check_sql_injection_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def text_input_check_sql_injection_with_http_info(self, value, **kwargs):  # noqa: E501
        """Check text input for SQL Injection (SQLI) attacks  # noqa: E501

        Detects SQL Injection (SQLI) attacks from text input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.text_input_check_sql_injection_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :param str detection_level: Set to Normal to target a high-security SQL Injection detection level with a very low false positive rate; select High to target a very-high security SQL Injection detection level with higher false positives.  Default is Normal (recommended).
        :return: SqlInjectionDetectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value', 'detection_level']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method text_input_check_sql_injection" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `text_input_check_sql_injection`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'detection_level' in params:
            header_params['detectionLevel'] = params['detection_level']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/text-input/check/sql-injection', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SqlInjectionDetectionResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def text_input_check_sql_injection_batch(self, value, **kwargs):  # noqa: E501
        """Check and protect multiple text inputs for SQL Injection (SQLI) attacks in batch  # noqa: E501

        Detects SQL Injection (SQLI) attacks from multiple text inputs.  Output preverses order of input items.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.text_input_check_sql_injection_batch(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SqlInjectionCheckBatchRequest value: User-facing text input. (required)
        :return: SqlInjectionCheckBatchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.text_input_check_sql_injection_batch_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.text_input_check_sql_injection_batch_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def text_input_check_sql_injection_batch_with_http_info(self, value, **kwargs):  # noqa: E501
        """Check and protect multiple text inputs for SQL Injection (SQLI) attacks in batch  # noqa: E501

        Detects SQL Injection (SQLI) attacks from multiple text inputs.  Output preverses order of input items.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.text_input_check_sql_injection_batch_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SqlInjectionCheckBatchRequest value: User-facing text input. (required)
        :return: SqlInjectionCheckBatchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method text_input_check_sql_injection_batch" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `text_input_check_sql_injection_batch`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/text-input/check/sql-injection/batch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SqlInjectionCheckBatchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def text_input_check_xss(self, value, **kwargs):  # noqa: E501
        """Check text input for Cross-Site-Scripting (XSS) attacks  # noqa: E501

        Detects XSS (Cross-Site-Scripting) attacks from text input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.text_input_check_xss(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: XssProtectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.text_input_check_xss_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.text_input_check_xss_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def text_input_check_xss_with_http_info(self, value, **kwargs):  # noqa: E501
        """Check text input for Cross-Site-Scripting (XSS) attacks  # noqa: E501

        Detects XSS (Cross-Site-Scripting) attacks from text input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.text_input_check_xss_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: XssProtectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method text_input_check_xss" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `text_input_check_xss`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/text-input/check/xss', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='XssProtectionResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def text_input_check_xss_batch(self, value, **kwargs):  # noqa: E501
        """Check and protect multiple text inputs for Cross-Site-Scripting (XSS) attacks in batch  # noqa: E501

        Detects XSS (Cross-Site-Scripting) attacks from multiple text inputs.  Output preverses order of input items.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.text_input_check_xss_batch(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param XssProtectionBatchRequest value: User-facing text input. (required)
        :return: XssProtectionBatchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.text_input_check_xss_batch_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.text_input_check_xss_batch_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def text_input_check_xss_batch_with_http_info(self, value, **kwargs):  # noqa: E501
        """Check and protect multiple text inputs for Cross-Site-Scripting (XSS) attacks in batch  # noqa: E501

        Detects XSS (Cross-Site-Scripting) attacks from multiple text inputs.  Output preverses order of input items.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.text_input_check_xss_batch_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param XssProtectionBatchRequest value: User-facing text input. (required)
        :return: XssProtectionBatchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method text_input_check_xss_batch" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `text_input_check_xss_batch`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/text-input/check-and-protect/xss/batch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='XssProtectionBatchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def text_input_protect_xss(self, value, **kwargs):  # noqa: E501
        """Protect text input from Cross-Site-Scripting (XSS) attacks through normalization  # noqa: E501

        Detects and removes XSS (Cross-Site-Scripting) attacks from text input through normalization.  Returns the normalized result, as well as information on whether the original input contained an XSS risk.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.text_input_protect_xss(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: XssProtectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.text_input_protect_xss_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.text_input_protect_xss_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def text_input_protect_xss_with_http_info(self, value, **kwargs):  # noqa: E501
        """Protect text input from Cross-Site-Scripting (XSS) attacks through normalization  # noqa: E501

        Detects and removes XSS (Cross-Site-Scripting) attacks from text input through normalization.  Returns the normalized result, as well as information on whether the original input contained an XSS risk.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.text_input_protect_xss_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: XssProtectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method text_input_protect_xss" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `text_input_protect_xss`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/text-input/protect/xss', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='XssProtectionResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_validate_api_client.api_client import ApiClient


class DateTimeApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def date_time_get_now_simple(self, **kwargs):  # noqa: E501
        """Get current date and time as of now  # noqa: E501

        Gets the current date and time.  Response time is syncronized with atomic clocks, and represents a monotonic, centrally available, consistent clock.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.date_time_get_now_simple(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: DateTimeNowResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.date_time_get_now_simple_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.date_time_get_now_simple_with_http_info(**kwargs)  # noqa: E501
            return data

    def date_time_get_now_simple_with_http_info(self, **kwargs):  # noqa: E501
        """Get current date and time as of now  # noqa: E501

        Gets the current date and time.  Response time is syncronized with atomic clocks, and represents a monotonic, centrally available, consistent clock.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.date_time_get_now_simple_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: DateTimeNowResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method date_time_get_now_simple" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/date-time/get/now', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DateTimeNowResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def date_time_get_public_holidays(self, input, **kwargs):  # noqa: E501
        """Get public holidays in the specified country and year  # noqa: E501

        Enumerates all public holidays in a given country for a given year.  Supports over 100 countries.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.date_time_get_public_holidays(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetPublicHolidaysRequest input: Input request (required)
        :return: PublicHolidaysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.date_time_get_public_holidays_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.date_time_get_public_holidays_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def date_time_get_public_holidays_with_http_info(self, input, **kwargs):  # noqa: E501
        """Get public holidays in the specified country and year  # noqa: E501

        Enumerates all public holidays in a given country for a given year.  Supports over 100 countries.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.date_time_get_public_holidays_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetPublicHolidaysRequest input: Input request (required)
        :return: PublicHolidaysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method date_time_get_public_holidays" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `date_time_get_public_holidays`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/date-time/get/holidays', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PublicHolidaysResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def date_time_parse_natural_language_date_time(self, input, **kwargs):  # noqa: E501
        """Parses a free-form natural language date and time string into a date and time  # noqa: E501

        Parses an unstructured, free-form, natural language date and time string into a date time object.  This is intended for lightweight human-entered input, such as \"tomorrow at 3pm\" or \"tuesday\".  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.date_time_parse_natural_language_date_time(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DateTimeNaturalLanguageParseRequest input: Input request (required)
        :return: DateTimeStandardizedParseResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.date_time_parse_natural_language_date_time_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.date_time_parse_natural_language_date_time_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def date_time_parse_natural_language_date_time_with_http_info(self, input, **kwargs):  # noqa: E501
        """Parses a free-form natural language date and time string into a date and time  # noqa: E501

        Parses an unstructured, free-form, natural language date and time string into a date time object.  This is intended for lightweight human-entered input, such as \"tomorrow at 3pm\" or \"tuesday\".  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.date_time_parse_natural_language_date_time_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DateTimeNaturalLanguageParseRequest input: Input request (required)
        :return: DateTimeStandardizedParseResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method date_time_parse_natural_language_date_time" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `date_time_parse_natural_language_date_time`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/date-time/parse/date-time/natural-language', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DateTimeStandardizedParseResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def date_time_parse_standard_date_time(self, input, **kwargs):  # noqa: E501
        """Parses a standardized date and time string into a date and time  # noqa: E501

        Parses a structured date and time string into a date time object.  This is intended for standardized date strings that adhere to formatting conventions, rather than natural language input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.date_time_parse_standard_date_time(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DateTimeStandardizedParseRequest input: Input request (required)
        :return: DateTimeStandardizedParseResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.date_time_parse_standard_date_time_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.date_time_parse_standard_date_time_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def date_time_parse_standard_date_time_with_http_info(self, input, **kwargs):  # noqa: E501
        """Parses a standardized date and time string into a date and time  # noqa: E501

        Parses a structured date and time string into a date time object.  This is intended for standardized date strings that adhere to formatting conventions, rather than natural language input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.date_time_parse_standard_date_time_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DateTimeStandardizedParseRequest input: Input request (required)
        :return: DateTimeStandardizedParseResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method date_time_parse_standard_date_time" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `date_time_parse_standard_date_time`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/date-time/parse/date-time/structured', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DateTimeStandardizedParseResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_validate_api_client.api_client import ApiClient


class EmailApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def email_address_get_servers(self, email, **kwargs):  # noqa: E501
        """Partially check whether an email address is valid  # noqa: E501

        Validate an email address by identifying whether its parent domain has email servers defined.  This call is less limited than syntaxOnly but not as comprehensive as address/full.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.email_address_get_servers(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: Email address to validate, e.g. \"support@cloudmersive.com\".    The input is a string so be sure to enclose it in double-quotes. (required)
        :return: AddressGetServersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.email_address_get_servers_with_http_info(email, **kwargs)  # noqa: E501
        else:
            (data) = self.email_address_get_servers_with_http_info(email, **kwargs)  # noqa: E501
            return data

    def email_address_get_servers_with_http_info(self, email, **kwargs):  # noqa: E501
        """Partially check whether an email address is valid  # noqa: E501

        Validate an email address by identifying whether its parent domain has email servers defined.  This call is less limited than syntaxOnly but not as comprehensive as address/full.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.email_address_get_servers_with_http_info(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: Email address to validate, e.g. \"support@cloudmersive.com\".    The input is a string so be sure to enclose it in double-quotes. (required)
        :return: AddressGetServersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method email_address_get_servers" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email' is set
        if ('email' not in params or
                params['email'] is None):
            raise ValueError("Missing the required parameter `email` when calling `email_address_get_servers`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'email' in params:
            body_params = params['email']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/email/address/servers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AddressGetServersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def email_full_validation(self, email, **kwargs):  # noqa: E501
        """Fully validate an email address  # noqa: E501

        Performs a full validation of the email address.  Checks for syntactic correctness, identifies the mail server in question if any, and then contacts the email server to validate the existence of the account - without sending any emails.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.email_full_validation(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: Email address to validate, e.g. \"support@cloudmersive.com\".    The input is a string so be sure to enclose it in double-quotes. (required)
        :return: FullEmailValidationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.email_full_validation_with_http_info(email, **kwargs)  # noqa: E501
        else:
            (data) = self.email_full_validation_with_http_info(email, **kwargs)  # noqa: E501
            return data

    def email_full_validation_with_http_info(self, email, **kwargs):  # noqa: E501
        """Fully validate an email address  # noqa: E501

        Performs a full validation of the email address.  Checks for syntactic correctness, identifies the mail server in question if any, and then contacts the email server to validate the existence of the account - without sending any emails.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.email_full_validation_with_http_info(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: Email address to validate, e.g. \"support@cloudmersive.com\".    The input is a string so be sure to enclose it in double-quotes. (required)
        :return: FullEmailValidationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method email_full_validation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email' is set
        if ('email' not in params or
                params['email'] is None):
            raise ValueError("Missing the required parameter `email` when calling `email_full_validation`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'email' in params:
            body_params = params['email']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/email/address/full', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FullEmailValidationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def email_post(self, value, **kwargs):  # noqa: E501
        """Validate email adddress for syntactic correctness only  # noqa: E501

        Validate whether a given email address is syntactically correct via a limited local-only check.  Use the address/full API to do a full validation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.email_post(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: Email address to validate, e.g. \"support@cloudmersive.com\".    The input is a string so be sure to enclose it in double-quotes. (required)
        :return: AddressVerifySyntaxOnlyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.email_post_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.email_post_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def email_post_with_http_info(self, value, **kwargs):  # noqa: E501
        """Validate email adddress for syntactic correctness only  # noqa: E501

        Validate whether a given email address is syntactically correct via a limited local-only check.  Use the address/full API to do a full validation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.email_post_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: Email address to validate, e.g. \"support@cloudmersive.com\".    The input is a string so be sure to enclose it in double-quotes. (required)
        :return: AddressVerifySyntaxOnlyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method email_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `email_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/email/address/syntaxOnly', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AddressVerifySyntaxOnlyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetTimezonesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'country_full_name': 'str',
        'iso_two_letter_code': 'str',
        'fips_two_letter_code': 'str',
        'three_letter_code': 'str',
        'timezones': 'list[Timezone]'
    }

    attribute_map = {
        'successful': 'Successful',
        'country_full_name': 'CountryFullName',
        'iso_two_letter_code': 'ISOTwoLetterCode',
        'fips_two_letter_code': 'FIPSTwoLetterCode',
        'three_letter_code': 'ThreeLetterCode',
        'timezones': 'Timezones'
    }

    def __init__(self, successful=None, country_full_name=None, iso_two_letter_code=None, fips_two_letter_code=None, three_letter_code=None, timezones=None):  # noqa: E501
        """GetTimezonesResponse - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._country_full_name = None
        self._iso_two_letter_code = None
        self._fips_two_letter_code = None
        self._three_letter_code = None
        self._timezones = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if country_full_name is not None:
            self.country_full_name = country_full_name
        if iso_two_letter_code is not None:
            self.iso_two_letter_code = iso_two_letter_code
        if fips_two_letter_code is not None:
            self.fips_two_letter_code = fips_two_letter_code
        if three_letter_code is not None:
            self.three_letter_code = three_letter_code
        if timezones is not None:
            self.timezones = timezones

    @property
    def successful(self):
        """Gets the successful of this GetTimezonesResponse.  # noqa: E501

        True if successful, false otherwise  # noqa: E501

        :return: The successful of this GetTimezonesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this GetTimezonesResponse.

        True if successful, false otherwise  # noqa: E501

        :param successful: The successful of this GetTimezonesResponse.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def country_full_name(self):
        """Gets the country_full_name of this GetTimezonesResponse.  # noqa: E501

        Full name of the country  # noqa: E501

        :return: The country_full_name of this GetTimezonesResponse.  # noqa: E501
        :rtype: str
        """
        return self._country_full_name

    @country_full_name.setter
    def country_full_name(self, country_full_name):
        """Sets the country_full_name of this GetTimezonesResponse.

        Full name of the country  # noqa: E501

        :param country_full_name: The country_full_name of this GetTimezonesResponse.  # noqa: E501
        :type: str
        """

        self._country_full_name = country_full_name

    @property
    def iso_two_letter_code(self):
        """Gets the iso_two_letter_code of this GetTimezonesResponse.  # noqa: E501

        Two-letter ISO 3166-1 country code  # noqa: E501

        :return: The iso_two_letter_code of this GetTimezonesResponse.  # noqa: E501
        :rtype: str
        """
        return self._iso_two_letter_code

    @iso_two_letter_code.setter
    def iso_two_letter_code(self, iso_two_letter_code):
        """Sets the iso_two_letter_code of this GetTimezonesResponse.

        Two-letter ISO 3166-1 country code  # noqa: E501

        :param iso_two_letter_code: The iso_two_letter_code of this GetTimezonesResponse.  # noqa: E501
        :type: str
        """

        self._iso_two_letter_code = iso_two_letter_code

    @property
    def fips_two_letter_code(self):
        """Gets the fips_two_letter_code of this GetTimezonesResponse.  # noqa: E501

        Two-letter FIPS 10-4 country code  # noqa: E501

        :return: The fips_two_letter_code of this GetTimezonesResponse.  # noqa: E501
        :rtype: str
        """
        return self._fips_two_letter_code

    @fips_two_letter_code.setter
    def fips_two_letter_code(self, fips_two_letter_code):
        """Sets the fips_two_letter_code of this GetTimezonesResponse.

        Two-letter FIPS 10-4 country code  # noqa: E501

        :param fips_two_letter_code: The fips_two_letter_code of this GetTimezonesResponse.  # noqa: E501
        :type: str
        """

        self._fips_two_letter_code = fips_two_letter_code

    @property
    def three_letter_code(self):
        """Gets the three_letter_code of this GetTimezonesResponse.  # noqa: E501

        Three-letter ISO 3166-1 country code  # noqa: E501

        :return: The three_letter_code of this GetTimezonesResponse.  # noqa: E501
        :rtype: str
        """
        return self._three_letter_code

    @three_letter_code.setter
    def three_letter_code(self, three_letter_code):
        """Sets the three_letter_code of this GetTimezonesResponse.

        Three-letter ISO 3166-1 country code  # noqa: E501

        :param three_letter_code: The three_letter_code of this GetTimezonesResponse.  # noqa: E501
        :type: str
        """

        self._three_letter_code = three_letter_code

    @property
    def timezones(self):
        """Gets the timezones of this GetTimezonesResponse.  # noqa: E501

        Time zones (IANA/Olsen) in the country  # noqa: E501

        :return: The timezones of this GetTimezonesResponse.  # noqa: E501
        :rtype: list[Timezone]
        """
        return self._timezones

    @timezones.setter
    def timezones(self, timezones):
        """Sets the timezones of this GetTimezonesResponse.

        Time zones (IANA/Olsen) in the country  # noqa: E501

        :param timezones: The timezones of this GetTimezonesResponse.  # noqa: E501
        :type: list[Timezone]
        """

        self._timezones = timezones

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetTimezonesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetTimezonesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_validate_api_client
from cloudmersive_validate_api_client.api.date_time_api import DateTimeApi  # noqa: E501
from cloudmersive_validate_api_client.rest import ApiException


class TestDateTimeApi(unittest.TestCase):
    """DateTimeApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_validate_api_client.api.date_time_api.DateTimeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_date_time_get_now_simple(self):
        """Test case for date_time_get_now_simple

        Get current date and time as of now  # noqa: E501
        """
        pass

    def test_date_time_get_public_holidays(self):
        """Test case for date_time_get_public_holidays

        Get public holidays in the specified country and year  # noqa: E501
        """
        pass

    def test_date_time_parse_natural_language_date_time(self):
        """Test case for date_time_parse_natural_language_date_time

        Parses a free-form natural language date and time string into a date and time  # noqa: E501
        """
        pass

    def test_date_time_parse_standard_date_time(self):
        """Test case for date_time_parse_standard_date_time

        Parses a standardized date and time string into a date and time  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from cloudmersive_validate_api_client.models.address_get_servers_response import AddressGetServersResponse
from cloudmersive_validate_api_client.models.address_verify_syntax_only_response import AddressVerifySyntaxOnlyResponse
from cloudmersive_validate_api_client.models.bot_check_response import BotCheckResponse
from cloudmersive_validate_api_client.models.check_response import CheckResponse
from cloudmersive_validate_api_client.models.country_details import CountryDetails
from cloudmersive_validate_api_client.models.country_list_result import CountryListResult
from cloudmersive_validate_api_client.models.date_time_natural_language_parse_request import DateTimeNaturalLanguageParseRequest
from cloudmersive_validate_api_client.models.date_time_now_result import DateTimeNowResult
from cloudmersive_validate_api_client.models.date_time_standardized_parse_request import DateTimeStandardizedParseRequest
from cloudmersive_validate_api_client.models.date_time_standardized_parse_response import DateTimeStandardizedParseResponse
from cloudmersive_validate_api_client.models.domain_quality_response import DomainQualityResponse
from cloudmersive_validate_api_client.models.first_name_validation_request import FirstNameValidationRequest
from cloudmersive_validate_api_client.models.first_name_validation_response import FirstNameValidationResponse
from cloudmersive_validate_api_client.models.full_email_validation_response import FullEmailValidationResponse
from cloudmersive_validate_api_client.models.full_name_validation_request import FullNameValidationRequest
from cloudmersive_validate_api_client.models.full_name_validation_response import FullNameValidationResponse
from cloudmersive_validate_api_client.models.geolocate_response import GeolocateResponse
from cloudmersive_validate_api_client.models.geolocate_street_address_response import GeolocateStreetAddressResponse
from cloudmersive_validate_api_client.models.get_gender_request import GetGenderRequest
from cloudmersive_validate_api_client.models.get_gender_response import GetGenderResponse
from cloudmersive_validate_api_client.models.get_public_holidays_request import GetPublicHolidaysRequest
from cloudmersive_validate_api_client.models.get_timezones_request import GetTimezonesRequest
from cloudmersive_validate_api_client.models.get_timezones_response import GetTimezonesResponse
from cloudmersive_validate_api_client.models.ip_intelligence_response import IPIntelligenceResponse
from cloudmersive_validate_api_client.models.ip_reverse_dns_lookup_response import IPReverseDNSLookupResponse
from cloudmersive_validate_api_client.models.ip_threat_response import IPThreatResponse
from cloudmersive_validate_api_client.models.last_name_validation_request import LastNameValidationRequest
from cloudmersive_validate_api_client.models.last_name_validation_response import LastNameValidationResponse
from cloudmersive_validate_api_client.models.lead_enrichment_request import LeadEnrichmentRequest
from cloudmersive_validate_api_client.models.lead_enrichment_response import LeadEnrichmentResponse
from cloudmersive_validate_api_client.models.normalize_address_response import NormalizeAddressResponse
from cloudmersive_validate_api_client.models.parse_address_request import ParseAddressRequest
from cloudmersive_validate_api_client.models.parse_address_response import ParseAddressResponse
from cloudmersive_validate_api_client.models.phishing_check_request import PhishingCheckRequest
from cloudmersive_validate_api_client.models.phishing_check_response import PhishingCheckResponse
from cloudmersive_validate_api_client.models.phone_number_validate_request import PhoneNumberValidateRequest
from cloudmersive_validate_api_client.models.phone_number_validation_response import PhoneNumberValidationResponse
from cloudmersive_validate_api_client.models.public_holiday_occurrence import PublicHolidayOccurrence
from cloudmersive_validate_api_client.models.public_holidays_response import PublicHolidaysResponse
from cloudmersive_validate_api_client.models.reverse_geocode_address_request import ReverseGeocodeAddressRequest
from cloudmersive_validate_api_client.models.reverse_geocode_address_response import ReverseGeocodeAddressResponse
from cloudmersive_validate_api_client.models.sql_injection_check_batch_request import SqlInjectionCheckBatchRequest
from cloudmersive_validate_api_client.models.sql_injection_check_batch_response import SqlInjectionCheckBatchResponse
from cloudmersive_validate_api_client.models.sql_injection_check_request_item import SqlInjectionCheckRequestItem
from cloudmersive_validate_api_client.models.sql_injection_detection_result import SqlInjectionDetectionResult
from cloudmersive_validate_api_client.models.timezone import Timezone
from cloudmersive_validate_api_client.models.tor_node_response import TorNodeResponse
from cloudmersive_validate_api_client.models.url_safety_check_request_full import UrlSafetyCheckRequestFull
from cloudmersive_validate_api_client.models.url_safety_check_response_full import UrlSafetyCheckResponseFull
from cloudmersive_validate_api_client.models.url_ssrf_request_batch import UrlSsrfRequestBatch
from cloudmersive_validate_api_client.models.url_ssrf_request_full import UrlSsrfRequestFull
from cloudmersive_validate_api_client.models.url_ssrf_response_batch import UrlSsrfResponseBatch
from cloudmersive_validate_api_client.models.url_ssrf_response_full import UrlSsrfResponseFull
from cloudmersive_validate_api_client.models.user_agent_validate_request import UserAgentValidateRequest
from cloudmersive_validate_api_client.models.user_agent_validate_response import UserAgentValidateResponse
from cloudmersive_validate_api_client.models.validate_address_request import ValidateAddressRequest
from cloudmersive_validate_api_client.models.validate_address_response import ValidateAddressResponse
from cloudmersive_validate_api_client.models.validate_city_request import ValidateCityRequest
from cloudmersive_validate_api_client.models.validate_city_response import ValidateCityResponse
from cloudmersive_validate_api_client.models.validate_country_request import ValidateCountryRequest
from cloudmersive_validate_api_client.models.validate_country_response import ValidateCountryResponse
from cloudmersive_validate_api_client.models.validate_identifier_request import ValidateIdentifierRequest
from cloudmersive_validate_api_client.models.validate_identifier_response import ValidateIdentifierResponse
from cloudmersive_validate_api_client.models.validate_postal_code_request import ValidatePostalCodeRequest
from cloudmersive_validate_api_client.models.validate_postal_code_response import ValidatePostalCodeResponse
from cloudmersive_validate_api_client.models.validate_state_request import ValidateStateRequest
from cloudmersive_validate_api_client.models.validate_state_response import ValidateStateResponse
from cloudmersive_validate_api_client.models.validate_url_request_full import ValidateUrlRequestFull
from cloudmersive_validate_api_client.models.validate_url_request_syntax_only import ValidateUrlRequestSyntaxOnly
from cloudmersive_validate_api_client.models.validate_url_response_full import ValidateUrlResponseFull
from cloudmersive_validate_api_client.models.validate_url_response_syntax_only import ValidateUrlResponseSyntaxOnly
from cloudmersive_validate_api_client.models.vat_lookup_request import VatLookupRequest
from cloudmersive_validate_api_client.models.vat_lookup_response import VatLookupResponse
from cloudmersive_validate_api_client.models.whois_response import WhoisResponse
from cloudmersive_validate_api_client.models.xss_protection_batch_request import XssProtectionBatchRequest
from cloudmersive_validate_api_client.models.xss_protection_batch_response import XssProtectionBatchResponse
from cloudmersive_validate_api_client.models.xss_protection_request_item import XssProtectionRequestItem
from cloudmersive_validate_api_client.models.xss_protection_result import XssProtectionResult



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ValidateAddressResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'valid_address': 'bool',
        'latitude': 'float',
        'longitude': 'float'
    }

    attribute_map = {
        'valid_address': 'ValidAddress',
        'latitude': 'Latitude',
        'longitude': 'Longitude'
    }

    def __init__(self, valid_address=None, latitude=None, longitude=None):  # noqa: E501
        """ValidateAddressResponse - a model defined in Swagger"""  # noqa: E501

        self._valid_address = None
        self._latitude = None
        self._longitude = None
        self.discriminator = None

        if valid_address is not None:
            self.valid_address = valid_address
        if latitude is not None:
            self.latitude = latitude
        if longitude is not None:
            self.longitude = longitude

    @property
    def valid_address(self):
        """Gets the valid_address of this ValidateAddressResponse.  # noqa: E501

        True if the address is valid, false otherwise  # noqa: E501

        :return: The valid_address of this ValidateAddressResponse.  # noqa: E501
        :rtype: bool
        """
        return self._valid_address

    @valid_address.setter
    def valid_address(self, valid_address):
        """Sets the valid_address of this ValidateAddressResponse.

        True if the address is valid, false otherwise  # noqa: E501

        :param valid_address: The valid_address of this ValidateAddressResponse.  # noqa: E501
        :type: bool
        """

        self._valid_address = valid_address

    @property
    def latitude(self):
        """Gets the latitude of this ValidateAddressResponse.  # noqa: E501

        If the address is valid, the degrees latitude of the validated address, null otherwise  # noqa: E501

        :return: The latitude of this ValidateAddressResponse.  # noqa: E501
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """Sets the latitude of this ValidateAddressResponse.

        If the address is valid, the degrees latitude of the validated address, null otherwise  # noqa: E501

        :param latitude: The latitude of this ValidateAddressResponse.  # noqa: E501
        :type: float
        """

        self._latitude = latitude

    @property
    def longitude(self):
        """Gets the longitude of this ValidateAddressResponse.  # noqa: E501

        If the address is valid, the degrees longitude of the validated address, null otherwise  # noqa: E501

        :return: The longitude of this ValidateAddressResponse.  # noqa: E501
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """Sets the longitude of this ValidateAddressResponse.

        If the address is valid, the degrees longitude of the validated address, null otherwise  # noqa: E501

        :param longitude: The longitude of this ValidateAddressResponse.  # noqa: E501
        :type: float
        """

        self._longitude = longitude

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ValidateAddressResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ValidateAddressResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetPublicHolidaysRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'raw_country_input': 'str',
        'year': 'int'
    }

    attribute_map = {
        'raw_country_input': 'RawCountryInput',
        'year': 'Year'
    }

    def __init__(self, raw_country_input=None, year=None):  # noqa: E501
        """GetPublicHolidaysRequest - a model defined in Swagger"""  # noqa: E501

        self._raw_country_input = None
        self._year = None
        self.discriminator = None

        if raw_country_input is not None:
            self.raw_country_input = raw_country_input
        if year is not None:
            self.year = year

    @property
    def raw_country_input(self):
        """Gets the raw_country_input of this GetPublicHolidaysRequest.  # noqa: E501

        Two-letter code (FIPS 10-4 or ISO 3166-1) of the country; if not specified, defaults to United States  # noqa: E501

        :return: The raw_country_input of this GetPublicHolidaysRequest.  # noqa: E501
        :rtype: str
        """
        return self._raw_country_input

    @raw_country_input.setter
    def raw_country_input(self, raw_country_input):
        """Sets the raw_country_input of this GetPublicHolidaysRequest.

        Two-letter code (FIPS 10-4 or ISO 3166-1) of the country; if not specified, defaults to United States  # noqa: E501

        :param raw_country_input: The raw_country_input of this GetPublicHolidaysRequest.  # noqa: E501
        :type: str
        """

        self._raw_country_input = raw_country_input

    @property
    def year(self):
        """Gets the year of this GetPublicHolidaysRequest.  # noqa: E501

        Optional - the year in which to retrieve the holidays; if left blank (0) it will default to the current year  # noqa: E501

        :return: The year of this GetPublicHolidaysRequest.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this GetPublicHolidaysRequest.

        Optional - the year in which to retrieve the holidays; if left blank (0) it will default to the current year  # noqa: E501

        :param year: The year of this GetPublicHolidaysRequest.  # noqa: E501
        :type: int
        """

        self._year = year

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetPublicHolidaysRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetPublicHolidaysRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ValidateStateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'state_or_province': 'str',
        'country_full_name': 'str',
        'country_code': 'str'
    }

    attribute_map = {
        'state_or_province': 'StateOrProvince',
        'country_full_name': 'CountryFullName',
        'country_code': 'CountryCode'
    }

    def __init__(self, state_or_province=None, country_full_name=None, country_code=None):  # noqa: E501
        """ValidateStateRequest - a model defined in Swagger"""  # noqa: E501

        self._state_or_province = None
        self._country_full_name = None
        self._country_code = None
        self.discriminator = None

        if state_or_province is not None:
            self.state_or_province = state_or_province
        if country_full_name is not None:
            self.country_full_name = country_full_name
        if country_code is not None:
            self.country_code = country_code

    @property
    def state_or_province(self):
        """Gets the state_or_province of this ValidateStateRequest.  # noqa: E501

        Required: State or province of the address to validate, such as 'California' or 'CA'  # noqa: E501

        :return: The state_or_province of this ValidateStateRequest.  # noqa: E501
        :rtype: str
        """
        return self._state_or_province

    @state_or_province.setter
    def state_or_province(self, state_or_province):
        """Sets the state_or_province of this ValidateStateRequest.

        Required: State or province of the address to validate, such as 'California' or 'CA'  # noqa: E501

        :param state_or_province: The state_or_province of this ValidateStateRequest.  # noqa: E501
        :type: str
        """

        self._state_or_province = state_or_province

    @property
    def country_full_name(self):
        """Gets the country_full_name of this ValidateStateRequest.  # noqa: E501

        Optional (recommended); Name of the country, such as 'United States'.  If left blank, and CountryCode is also left blank, will default to United States.  Global countries are supported.  # noqa: E501

        :return: The country_full_name of this ValidateStateRequest.  # noqa: E501
        :rtype: str
        """
        return self._country_full_name

    @country_full_name.setter
    def country_full_name(self, country_full_name):
        """Sets the country_full_name of this ValidateStateRequest.

        Optional (recommended); Name of the country, such as 'United States'.  If left blank, and CountryCode is also left blank, will default to United States.  Global countries are supported.  # noqa: E501

        :param country_full_name: The country_full_name of this ValidateStateRequest.  # noqa: E501
        :type: str
        """

        self._country_full_name = country_full_name

    @property
    def country_code(self):
        """Gets the country_code of this ValidateStateRequest.  # noqa: E501

        Optional; two-letter country code (Two-letter ISO 3166-1 country code) of the country.  If left blank, and CountryFullName is also left blank, will default to United States.  Global countries are supported.  # noqa: E501

        :return: The country_code of this ValidateStateRequest.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this ValidateStateRequest.

        Optional; two-letter country code (Two-letter ISO 3166-1 country code) of the country.  If left blank, and CountryFullName is also left blank, will default to United States.  Global countries are supported.  # noqa: E501

        :param country_code: The country_code of this ValidateStateRequest.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ValidateStateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ValidateStateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AddressVerifySyntaxOnlyResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'valid_address': 'bool',
        'domain': 'str',
        'is_free_email_provider': 'bool',
        'is_disposable': 'bool'
    }

    attribute_map = {
        'valid_address': 'ValidAddress',
        'domain': 'Domain',
        'is_free_email_provider': 'IsFreeEmailProvider',
        'is_disposable': 'IsDisposable'
    }

    def __init__(self, valid_address=None, domain=None, is_free_email_provider=None, is_disposable=None):  # noqa: E501
        """AddressVerifySyntaxOnlyResponse - a model defined in Swagger"""  # noqa: E501

        self._valid_address = None
        self._domain = None
        self._is_free_email_provider = None
        self._is_disposable = None
        self.discriminator = None

        if valid_address is not None:
            self.valid_address = valid_address
        if domain is not None:
            self.domain = domain
        if is_free_email_provider is not None:
            self.is_free_email_provider = is_free_email_provider
        if is_disposable is not None:
            self.is_disposable = is_disposable

    @property
    def valid_address(self):
        """Gets the valid_address of this AddressVerifySyntaxOnlyResponse.  # noqa: E501

        True if the email address is syntactically valid, false if it is not  # noqa: E501

        :return: The valid_address of this AddressVerifySyntaxOnlyResponse.  # noqa: E501
        :rtype: bool
        """
        return self._valid_address

    @valid_address.setter
    def valid_address(self, valid_address):
        """Sets the valid_address of this AddressVerifySyntaxOnlyResponse.

        True if the email address is syntactically valid, false if it is not  # noqa: E501

        :param valid_address: The valid_address of this AddressVerifySyntaxOnlyResponse.  # noqa: E501
        :type: bool
        """

        self._valid_address = valid_address

    @property
    def domain(self):
        """Gets the domain of this AddressVerifySyntaxOnlyResponse.  # noqa: E501

        Domain name of the email address  # noqa: E501

        :return: The domain of this AddressVerifySyntaxOnlyResponse.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this AddressVerifySyntaxOnlyResponse.

        Domain name of the email address  # noqa: E501

        :param domain: The domain of this AddressVerifySyntaxOnlyResponse.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def is_free_email_provider(self):
        """Gets the is_free_email_provider of this AddressVerifySyntaxOnlyResponse.  # noqa: E501

        True if the email domain name is a free provider (typically a free to sign up web email provider for consumers / personal use), false otherwise.  # noqa: E501

        :return: The is_free_email_provider of this AddressVerifySyntaxOnlyResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_free_email_provider

    @is_free_email_provider.setter
    def is_free_email_provider(self, is_free_email_provider):
        """Sets the is_free_email_provider of this AddressVerifySyntaxOnlyResponse.

        True if the email domain name is a free provider (typically a free to sign up web email provider for consumers / personal use), false otherwise.  # noqa: E501

        :param is_free_email_provider: The is_free_email_provider of this AddressVerifySyntaxOnlyResponse.  # noqa: E501
        :type: bool
        """

        self._is_free_email_provider = is_free_email_provider

    @property
    def is_disposable(self):
        """Gets the is_disposable of this AddressVerifySyntaxOnlyResponse.  # noqa: E501

        True if the email address is a disposable email address, false otherwise; these disposable providers are not typically used to receive email and so will have a low likelihood of opening mail sent there.  # noqa: E501

        :return: The is_disposable of this AddressVerifySyntaxOnlyResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_disposable

    @is_disposable.setter
    def is_disposable(self, is_disposable):
        """Sets the is_disposable of this AddressVerifySyntaxOnlyResponse.

        True if the email address is a disposable email address, false otherwise; these disposable providers are not typically used to receive email and so will have a low likelihood of opening mail sent there.  # noqa: E501

        :param is_disposable: The is_disposable of this AddressVerifySyntaxOnlyResponse.  # noqa: E501
        :type: bool
        """

        self._is_disposable = is_disposable

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddressVerifySyntaxOnlyResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddressVerifySyntaxOnlyResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from cloudmersive_validate_api_client.api.address_api import AddressApi
from cloudmersive_validate_api_client.api.date_time_api import DateTimeApi
from cloudmersive_validate_api_client.api.domain_api import DomainApi
from cloudmersive_validate_api_client.api.email_api import EmailApi
from cloudmersive_validate_api_client.api.ip_address_api import IPAddressApi
from cloudmersive_validate_api_client.api.lead_enrichment_api import LeadEnrichmentApi
from cloudmersive_validate_api_client.api.name_api import NameApi
from cloudmersive_validate_api_client.api.phone_number_api import PhoneNumberApi
from cloudmersive_validate_api_client.api.text_input_api import TextInputApi
from cloudmersive_validate_api_client.api.user_agent_api import UserAgentApi
from cloudmersive_validate_api_client.api.vat_api import VatApi



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.vat_api import VatApi  # noqa: E501
from swagger_client.rest import ApiException


class TestVatApi(unittest.TestCase):
    """VatApi unit test stubs"""

    def setUp(self):
        self.api = swagger_client.api.vat_api.VatApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_vat_vat_lookup(self):
        """Test case for vat_vat_lookup

        Lookup a VAT code  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ParseAddressResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'building': 'str',
        'street_number': 'str',
        'street': 'str',
        'city': 'str',
        'state_or_province': 'str',
        'postal_code': 'str',
        'country_full_name': 'str',
        'iso_two_letter_code': 'str'
    }

    attribute_map = {
        'successful': 'Successful',
        'building': 'Building',
        'street_number': 'StreetNumber',
        'street': 'Street',
        'city': 'City',
        'state_or_province': 'StateOrProvince',
        'postal_code': 'PostalCode',
        'country_full_name': 'CountryFullName',
        'iso_two_letter_code': 'ISOTwoLetterCode'
    }

    def __init__(self, successful=None, building=None, street_number=None, street=None, city=None, state_or_province=None, postal_code=None, country_full_name=None, iso_two_letter_code=None):  # noqa: E501
        """ParseAddressResponse - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._building = None
        self._street_number = None
        self._street = None
        self._city = None
        self._state_or_province = None
        self._postal_code = None
        self._country_full_name = None
        self._iso_two_letter_code = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if building is not None:
            self.building = building
        if street_number is not None:
            self.street_number = street_number
        if street is not None:
            self.street = street
        if city is not None:
            self.city = city
        if state_or_province is not None:
            self.state_or_province = state_or_province
        if postal_code is not None:
            self.postal_code = postal_code
        if country_full_name is not None:
            self.country_full_name = country_full_name
        if iso_two_letter_code is not None:
            self.iso_two_letter_code = iso_two_letter_code

    @property
    def successful(self):
        """Gets the successful of this ParseAddressResponse.  # noqa: E501

        True if the parsing operation was successful, false otherwise  # noqa: E501

        :return: The successful of this ParseAddressResponse.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this ParseAddressResponse.

        True if the parsing operation was successful, false otherwise  # noqa: E501

        :param successful: The successful of this ParseAddressResponse.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def building(self):
        """Gets the building of this ParseAddressResponse.  # noqa: E501

        The name of the building, house or structure if applicable, such as \"Cloudmersive Building 2\".  This will often by null.  # noqa: E501

        :return: The building of this ParseAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._building

    @building.setter
    def building(self, building):
        """Sets the building of this ParseAddressResponse.

        The name of the building, house or structure if applicable, such as \"Cloudmersive Building 2\".  This will often by null.  # noqa: E501

        :param building: The building of this ParseAddressResponse.  # noqa: E501
        :type: str
        """

        self._building = building

    @property
    def street_number(self):
        """Gets the street_number of this ParseAddressResponse.  # noqa: E501

        The street number or house number of the address.  For example, in the address \"1600 Pennsylvania Avenue NW\" the street number would be \"1600\".  This value will typically be populated for most addresses.  # noqa: E501

        :return: The street_number of this ParseAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._street_number

    @street_number.setter
    def street_number(self, street_number):
        """Sets the street_number of this ParseAddressResponse.

        The street number or house number of the address.  For example, in the address \"1600 Pennsylvania Avenue NW\" the street number would be \"1600\".  This value will typically be populated for most addresses.  # noqa: E501

        :param street_number: The street_number of this ParseAddressResponse.  # noqa: E501
        :type: str
        """

        self._street_number = street_number

    @property
    def street(self):
        """Gets the street of this ParseAddressResponse.  # noqa: E501

        The name of the street or road of the address.  For example, in the address \"1600 Pennsylvania Avenue NW\" the street number would be \"Pennsylvania Avenue NW\".  # noqa: E501

        :return: The street of this ParseAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """Sets the street of this ParseAddressResponse.

        The name of the street or road of the address.  For example, in the address \"1600 Pennsylvania Avenue NW\" the street number would be \"Pennsylvania Avenue NW\".  # noqa: E501

        :param street: The street of this ParseAddressResponse.  # noqa: E501
        :type: str
        """

        self._street = street

    @property
    def city(self):
        """Gets the city of this ParseAddressResponse.  # noqa: E501

        The city of the address.  # noqa: E501

        :return: The city of this ParseAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this ParseAddressResponse.

        The city of the address.  # noqa: E501

        :param city: The city of this ParseAddressResponse.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state_or_province(self):
        """Gets the state_or_province of this ParseAddressResponse.  # noqa: E501

        The state or province of the address.  # noqa: E501

        :return: The state_or_province of this ParseAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._state_or_province

    @state_or_province.setter
    def state_or_province(self, state_or_province):
        """Sets the state_or_province of this ParseAddressResponse.

        The state or province of the address.  # noqa: E501

        :param state_or_province: The state_or_province of this ParseAddressResponse.  # noqa: E501
        :type: str
        """

        self._state_or_province = state_or_province

    @property
    def postal_code(self):
        """Gets the postal_code of this ParseAddressResponse.  # noqa: E501

        The postal code or zip code of the address.  # noqa: E501

        :return: The postal_code of this ParseAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this ParseAddressResponse.

        The postal code or zip code of the address.  # noqa: E501

        :param postal_code: The postal_code of this ParseAddressResponse.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def country_full_name(self):
        """Gets the country_full_name of this ParseAddressResponse.  # noqa: E501

        Country of the address, if present in the address.  If not included in the address it will be null.  # noqa: E501

        :return: The country_full_name of this ParseAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._country_full_name

    @country_full_name.setter
    def country_full_name(self, country_full_name):
        """Sets the country_full_name of this ParseAddressResponse.

        Country of the address, if present in the address.  If not included in the address it will be null.  # noqa: E501

        :param country_full_name: The country_full_name of this ParseAddressResponse.  # noqa: E501
        :type: str
        """

        self._country_full_name = country_full_name

    @property
    def iso_two_letter_code(self):
        """Gets the iso_two_letter_code of this ParseAddressResponse.  # noqa: E501

        Two-letter ISO 3166-1 country code  # noqa: E501

        :return: The iso_two_letter_code of this ParseAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._iso_two_letter_code

    @iso_two_letter_code.setter
    def iso_two_letter_code(self, iso_two_letter_code):
        """Sets the iso_two_letter_code of this ParseAddressResponse.

        Two-letter ISO 3166-1 country code  # noqa: E501

        :param iso_two_letter_code: The iso_two_letter_code of this ParseAddressResponse.  # noqa: E501
        :type: str
        """

        self._iso_two_letter_code = iso_two_letter_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ParseAddressResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParseAddressResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
